package writer2latex.rdf;

import org.w3c.dom.Document;
import org.w3c.dom.Element;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;
import org.w3c.dom.ls.DOMImplementationLS;
import org.w3c.dom.ls.LSSerializer;

import writer2latex.xhtml.XhtmlDocument;

public class DocumentPart {

	private XhtmlDocument excerptDoc;
	private String path;
	private String itemNumber;
	private String body;
	private String parentPath;
	private String name;

	public DocumentPart(XhtmlDocument document) {
		this.excerptDoc = document;
		extractPath();
		extractName();
		extractNumber();
		extractBody();
		calculateParentPath();
	}
	public DocumentPart(String path) {
		this.path = path;
		this.name = "";
		extractNumber();
		this.body = "";
		calculateParentPath();
	}
	private void extractName() {
		Element excerptContentNode = excerptDoc.getContentNode();
		this.name = excerptContentNode.getAttribute("name");		
	}
	private void extractNumber() {
		itemNumber = path.replaceAll("([0-9]+ )+", "");
	}
	public String getPath() {
		return path;
	}
	public String getSafePath(){
		return path.replaceAll(" ","_");
	}
	public String getNumber() {
		return itemNumber;
	}
	public String getBody() {
		return body;
	}
	public String getParentPath() {
		return parentPath;
	}
	public String getName() {
		if (name.isEmpty()) {
			return "NONAME";
		}
		return name;
	}
	
	private void extractPath() {
		Element excerptContentNode = excerptDoc.getContentNode();
		this.path = excerptContentNode.getAttribute("path");
	}
	
	private void calculateParentPath() {
		if(path.length() == 1) {
			parentPath = "";
		} else {
			parentPath = path.replaceAll(" [0-9]+$", "");	
		}
	}
	private void extractBody() {
		Element excerptContentNode = excerptDoc.getContentNode();
		StringBuilder bodyBuilder;
		Document document = excerptContentNode.getOwnerDocument();
		DOMImplementationLS domImplLS = (DOMImplementationLS) document.getImplementation();
		LSSerializer serializer = domImplLS.createLSSerializer();
		serializer.getDomConfig().setParameter("xml-declaration", false);
		bodyBuilder = new StringBuilder();
		NodeList excerptContentNodes = excerptContentNode.getChildNodes();
		int i = 0;
		while (excerptContentNodes.getLength() > i) {
			Node child = excerptContentNodes.item(i);
			bodyBuilder.append(serializer.writeToString(child));
			i++;

		}
		this.body = bodyBuilder.toString();
	}
}
